# -*- coding: utf-8 -*-
from setuphelpers import *

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_name = "MBSetup.exe"
silentflags = "/VERYSILENT /SUPPRESSMSGBOXES /NORESTART"
app_uninstallkey = "{35065F43-4BB2-439A-BFF7-0F1014F2E0CD}_is1"
app_editor_dir = makepath(programfiles, "Malwarebytes")
app_dir = makepath(programfiles, "Malwarebytes", "Anti-Malware")
bin_path = makepath(app_dir, "mbuns.exe")


def install():
    # Declaring local variables
    package_version = control.get_software_version()

    # Installing the software
    print("Installing: %s (%s)" % (control.name, package_version))
    install_exe_if_needed(bin_name, silentflags=silentflags, key=app_uninstallkey, min_version="", timeout=600)

    # Avoiding the usage by WAPT of the app built-in Uninstallstring
    uninstallkey.remove(app_uninstallkey)


def audit():
    # Declaring local variables
    package_version = control.version.split("-", 1)[0]
    app_name = control.name

    # Getting installed software version
    if installed_softwares(uninstallkey=app_uninstallkey):
        installed_version = installed_softwares(uninstallkey=app_uninstallkey)[0]["version"]
    else:
        installed_version = None

    # Auditing software
    print("Auditing: %s" % control.package)
    if installed_version is None:
        print("%s is not installed" % (app_name, installed_version))
        return "ERROR"
    else:
        print("%s is installed in correct version (%s)" % (app_name, installed_version))
        return "OK"


def uninstall():
    # Uninstalling the software
    for to_uninstall in installed_softwares(app_uninstallkey):
        print("Removing: %s (%s)" % (to_uninstall["name"], to_uninstall["version"]))
        killalltasks(control.impacted_process.split(","))
        run([bin_path] + ["/VERYSILENT"] + ["/NORESTART"])
        wait_uninstallkey_absent(to_uninstall["key"])
    """ if service_installed("MBAMService"):
        service_delete("MBAMService") """
    """ if isdir(app_dir):
        killalltasks(control.impacted_process.split(","))
        print("Removing: %s" % (app_dir))
        remove_tree(app_dir)
    if isdir(app_editor_dir) and dir_is_empty(app_editor_dir):
        print("Removing: %s since he is empty" % (app_editor_dir))
        remove_tree(app_editor_dir) """
